==> huaweicloudsdkdli-3.1.40-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/list_queue_plans_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListQueuePlansResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'is_success': 'bool',
        'message': 'str',
        'plans': 'list[QueuePlanEntity]'
    }

    attribute_map = {
        'is_success': 'is_success',
        'message': 'message',
        'plans': 'plans'
    }

    def __init__(self, is_success=None, message=None, plans=None):
        """ListQueuePlansResponse

        The model defined in huaweicloud sdk

        :param is_success: 请求执行是否成功。“true”表示请求执行成功。
        :type is_success: bool
        :param message: 系统提示信息，执行成功时，信息可能为空。
        :type message: str
        :param plans: 定时扩缩容信息
        :type plans: list[:class:`huaweicloudsdkdli.v1.QueuePlanEntity`]
        """
        
        super(ListQueuePlansResponse, self).__init__()

        self._is_success = None
        self._message = None
        self._plans = None
        self.discriminator = None

        if is_success is not None:
            self.is_success = is_success
        if message is not None:
            self.message = message
        if plans is not None:
            self.plans = plans

    @property
    def is_success(self):
        """Gets the is_success of this ListQueuePlansResponse.

        请求执行是否成功。“true”表示请求执行成功。

        :return: The is_success of this ListQueuePlansResponse.
        :rtype: bool
        """
        return self._is_success

    @is_success.setter
    def is_success(self, is_success):
        """Sets the is_success of this ListQueuePlansResponse.

        请求执行是否成功。“true”表示请求执行成功。

        :param is_success: The is_success of this ListQueuePlansResponse.
        :type is_success: bool
        """
        self._is_success = is_success

    @property
    def message(self):
        """Gets the message of this ListQueuePlansResponse.

        系统提示信息，执行成功时，信息可能为空。

        :return: The message of this ListQueuePlansResponse.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ListQueuePlansResponse.

        系统提示信息，执行成功时，信息可能为空。

        :param message: The message of this ListQueuePlansResponse.
        :type message: str
        """
        self._message = message

    @property
    def plans(self):
        """Gets the plans of this ListQueuePlansResponse.

        定时扩缩容信息

        :return: The plans of this ListQueuePlansResponse.
        :rtype: list[:class:`huaweicloudsdkdli.v1.QueuePlanEntity`]
        """
        return self._plans

    @plans.setter
    def plans(self, plans):
        """Sets the plans of this ListQueuePlansResponse.

        定时扩缩容信息

        :param plans: The plans of this ListQueuePlansResponse.
        :type plans: list[:class:`huaweicloudsdkdli.v1.QueuePlanEntity`]
        """
        self._plans = plans

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListQueuePlansResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdli-3.1.138-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/list_queue_plans_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListQueuePlansResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'is_success': 'bool',
        'message': 'str',
        'plans': 'list[QueuePlan]'
    }

    attribute_map = {
        'is_success': 'is_success',
        'message': 'message',
        'plans': 'plans'
    }

    def __init__(self, is_success=None, message=None, plans=None):
        """ListQueuePlansResponse

        The model defined in huaweicloud sdk

        :param is_success: 请求执行是否成功。“true”表示请求执行成功。
        :type is_success: bool
        :param message: 系统提示信息，执行成功时，信息可能为空。
        :type message: str
        :param plans: 定时扩缩容信息
        :type plans: list[:class:`huaweicloudsdkdli.v1.QueuePlan`]
        """
        
        super(ListQueuePlansResponse, self).__init__()

        self._is_success = None
        self._message = None
        self._plans = None
        self.discriminator = None

        if is_success is not None:
            self.is_success = is_success
        if message is not None:
            self.message = message
        if plans is not None:
            self.plans = plans

    @property
    def is_success(self):
        """Gets the is_success of this ListQueuePlansResponse.

        请求执行是否成功。“true”表示请求执行成功。

        :return: The is_success of this ListQueuePlansResponse.
        :rtype: bool
        """
        return self._is_success

    @is_success.setter
    def is_success(self, is_success):
        """Sets the is_success of this ListQueuePlansResponse.

        请求执行是否成功。“true”表示请求执行成功。

        :param is_success: The is_success of this ListQueuePlansResponse.
        :type is_success: bool
        """
        self._is_success = is_success

    @property
    def message(self):
        """Gets the message of this ListQueuePlansResponse.

        系统提示信息，执行成功时，信息可能为空。

        :return: The message of this ListQueuePlansResponse.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ListQueuePlansResponse.

        系统提示信息，执行成功时，信息可能为空。

        :param message: The message of this ListQueuePlansResponse.
        :type message: str
        """
        self._message = message

    @property
    def plans(self):
        """Gets the plans of this ListQueuePlansResponse.

        定时扩缩容信息

        :return: The plans of this ListQueuePlansResponse.
        :rtype: list[:class:`huaweicloudsdkdli.v1.QueuePlan`]
        """
        return self._plans

    @plans.setter
    def plans(self, plans):
        """Sets the plans of this ListQueuePlansResponse.

        定时扩缩容信息

        :param plans: The plans of this ListQueuePlansResponse.
        :type plans: list[:class:`huaweicloudsdkdli.v1.QueuePlan`]
        """
        self._plans = plans

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListQueuePlansResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
